@@ -6,11 +6,9 @@
 
 import argparse
 import logging
-import sys
 import unittest
 
 from nose2 import config, util
-import six
 
 log = logging.getLogger(__name__)
 __unittest = True
@@ -52,8 +50,7 @@ class PluginMeta(type):
         return instance
 
 
-class Plugin(six.with_metaclass(PluginMeta)):
-
+class Plugin(metaclass=PluginMeta):
     """Base class for nose2 plugins
 
     All nose2 plugins must subclass this class.
@@ -185,7 +182,7 @@ class Plugin(six.with_metaclass(PluginMeta)):
 
         class CB(argparse.Action):
             def __call__(self, parser, namespace, values, option_string=None):
-                if six.callable(callback):
+                if callable(callback):
                     callback(values)
                 elif isinstance(callback, list):
                     callback.extend(values)
@@ -208,8 +205,7 @@ class Plugin(six.with_metaclass(PluginMeta)):
         )
 
 
-class Hook(object):
-
+class Hook:
     """A plugin hook
 
     Each plugin method in the :class:`nose2.events.PluginInterface` is
@@ -241,8 +237,7 @@ class Hook(object):
             self.plugins.append(plugin)
 
 
-class PluginInterface(object):
-
+class PluginInterface:
     """Definition of plugin interface.
 
     Instances of this class contain the methods that may be called,
@@ -348,8 +343,7 @@ class PluginInterface(object):
         return self.hooks.setdefault(attr, self.hookClass(attr))
 
 
-class Event(object):
-
+class Event:
     """Base class for all events.
 
     .. attribute :: metadata
@@ -377,13 +371,13 @@ class Event(object):
         self.metadata.update(metadata)
 
     def __str__(self):
-        return "%s(%s)" % (self.__class__.__name__, self._format())
+        return f"{self.__class__.__name__}({self._format()})"
 
     def __repr__(self):
         return str(self)
 
     def _format(self):
-        return ", ".join(["%s=%r" % (k, getattr(self, k, None)) for k in self._attrs])
+        return ", ".join([f"{k}={getattr(self, k, None)!r}" for k in self._attrs])
 
     def __getstate__(self):
         state = self.__dict__.copy()
@@ -392,9 +386,8 @@ class Event(object):
             test = state["test"]
             state["test"] = util.test_name(test)
             # subtest support
-            if sys.version_info >= (3, 4):
-                if isinstance(test, unittest.case._SubTest):
-                    state["metadata"]["subtest"] = (test._message, test.params)
+            if isinstance(test, unittest.case._SubTest):
+                state["metadata"]["subtest"] = (test._message, test.params)
         if "executeTests" in state:
             state["executeTests"] = None
         if "exc_info" in state and state["exc_info"] is not None:
@@ -408,7 +401,6 @@ class Event(object):
 
 
 class PluginsLoadedEvent(Event):
-
     """Event fired after all plugin classes are loaded.
 
     .. attribute :: pluginsLoaded
@@ -421,11 +413,10 @@ class PluginsLoadedEvent(Event):
 
     def __init__(self, pluginsLoaded, **kw):
         self.pluginsLoaded = pluginsLoaded
-        super(PluginsLoadedEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class RunnerCreatedEvent(Event):
-
     """Event fired when test runner is created.
 
     .. attribute :: runner
@@ -439,11 +430,10 @@ class RunnerCreatedEvent(Event):
 
     def __init__(self, runner, **kw):
         self.runner = runner
-        super(RunnerCreatedEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class ResultCreatedEvent(Event):
-
     """Event fired when test result handler is created.
 
     .. attribute :: result
@@ -457,11 +447,10 @@ class ResultCreatedEvent(Event):
 
     def __init__(self, result, **kw):
         self.result = result
-        super(ResultCreatedEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class StartLayerSetupEvent(Event):
-
     """Event fired before running a layer setup.
 
     .. attribute :: layer
@@ -473,11 +462,10 @@ class StartLayerSetupEvent(Event):
 
     def __init__(self, layer, **kw):
         self.layer = layer
-        super(StartLayerSetupEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class StopLayerSetupEvent(Event):
-
     """Event fired after running a layer setup.
 
     .. attribute :: layer
@@ -489,11 +477,10 @@ class StopLayerSetupEvent(Event):
 
     def __init__(self, layer, **kw):
         self.layer = layer
-        super(StopLayerSetupEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class StartLayerSetupTestEvent(Event):
-
     """Event fired before test cases setups in layers.
 
     .. attribute :: layer
@@ -510,11 +497,10 @@ class StartLayerSetupTestEvent(Event):
     def __init__(self, layer, test, **kw):
         self.layer = layer
         self.test = test
-        super(StartLayerSetupTestEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class StopLayerSetupTestEvent(Event):
-
     """Event fired after test cases setups in layers.
 
     .. attribute :: layer
@@ -531,11 +517,10 @@ class StopLayerSetupTestEvent(Event):
     def __init__(self, layer, test, **kw):
         self.layer = layer
         self.test = test
-        super(StopLayerSetupTestEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class StartLayerTeardownEvent(Event):
-
     """Event fired before running a layer teardown.
 
     .. attribute :: layer
@@ -547,11 +532,10 @@ class StartLayerTeardownEvent(Event):
 
     def __init__(self, layer, **kw):
         self.layer = layer
-        super(StartLayerTeardownEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class StopLayerTeardownEvent(Event):
-
     """Event fired after running a layer teardown.
 
     .. attribute :: layer
@@ -563,11 +547,10 @@ class StopLayerTeardownEvent(Event):
 
     def __init__(self, layer, **kw):
         self.layer = layer
-        super(StopLayerTeardownEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class StartLayerTeardownTestEvent(Event):
-
     """Event fired before test cases teardowns in layers.
 
     .. attribute :: layer
@@ -584,11 +567,10 @@ class StartLayerTeardownTestEvent(Event):
     def __init__(self, layer, test, **kw):
         self.layer = layer
         self.test = test
-        super(StartLayerTeardownTestEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class StopLayerTeardownTestEvent(Event):
-
     """Event fired after test cases teardowns in layers.
 
     .. attribute :: layer
@@ -605,11 +587,10 @@ class StopLayerTeardownTestEvent(Event):
     def __init__(self, layer, test, **kw):
         self.layer = layer
         self.test = test
-        super(StopLayerTeardownTestEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class StartTestRunEvent(Event):
-
     """Event fired when test run is about to start.
 
     Test collection is complete before this event fires, but
@@ -656,11 +637,10 @@ class StartTestRunEvent(Event):
         self.result = result
         self.startTime = startTime
         self.executeTests = executeTests
-        super(StartTestRunEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class StopTestRunEvent(Event):
-
     """Event fired when test run has stopped.
 
     .. attribute :: runner
@@ -688,11 +668,10 @@ class StopTestRunEvent(Event):
         self.result = result
         self.stopTime = stopTime
         self.timeTaken = timeTaken
-        super(StopTestRunEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class StartTestEvent(Event):
-
     """Event fired before a test is executed.
 
     .. attribute :: test
@@ -715,11 +694,10 @@ class StartTestEvent(Event):
         self.test = test
         self.result = result
         self.startTime = startTime
-        super(StartTestEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class StopTestEvent(Event):
-
     """Event fired after a test is executed.
 
     .. attribute :: test
@@ -742,11 +720,10 @@ class StopTestEvent(Event):
         self.test = test
         self.result = result
         self.stopTime = stopTime
-        super(StopTestEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class TestOutcomeEvent(Event):
-
     """Event fired when a test completes.
 
     .. attribute :: test
@@ -819,7 +796,7 @@ class TestOutcomeEvent(Event):
         expected=False,
         shortLabel=None,
         longLabel=None,
-        **kw
+        **kw,
     ):
         self.test = test
         self.result = result
@@ -829,11 +806,10 @@ class TestOutcomeEvent(Event):
         self.expected = expected
         self.shortLabel = shortLabel
         self.longLabel = longLabel
-        super(TestOutcomeEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class LoadFromModuleEvent(Event):
-
     """Event fired when a test module is loaded.
 
     .. attribute :: loader
@@ -863,7 +839,7 @@ class LoadFromModuleEvent(Event):
         self.loader = loader
         self.module = module
         self.extraTests = []
-        super(LoadFromModuleEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class ModuleSuiteEvent(Event):
@@ -873,11 +849,10 @@ class ModuleSuiteEvent(Event):
         self.loader = loader
         self.module = module
         self.suite = suite
-        super(ModuleSuiteEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class LoadFromTestCaseEvent(Event):
-
     """Event fired when tests are loaded from a test case.
 
     .. attribute :: loader
@@ -907,11 +882,10 @@ class LoadFromTestCaseEvent(Event):
         self.loader = loader
         self.testCase = testCase
         self.extraTests = []
-        super(LoadFromTestCaseEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class LoadFromNamesEvent(Event):
-
     """Event fired to load tests from test names.
 
     .. attribute :: loader
@@ -947,14 +921,13 @@ class LoadFromNamesEvent(Event):
         self.names = names
         self.module = module
         self.extraTests = []
-        super(LoadFromNamesEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
     def __str__(self):
-        return "LoadFromNames(names=%r, module=%r)" % (self.names, self.module)
+        return f"LoadFromNames(names={self.names!r}, module={self.module!r})"
 
 
 class LoadFromNameEvent(Event):
-
     """Event fired to load tests from test names.
 
     .. attribute :: loader
@@ -990,11 +963,10 @@ class LoadFromNameEvent(Event):
         self.name = name
         self.module = module
         self.extraTests = []
-        super(LoadFromNameEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class HandleFileEvent(Event):
-
     """Event fired when a non-test file is examined.
 
     .. note ::
@@ -1046,11 +1018,10 @@ class HandleFileEvent(Event):
         # note: pattern may be None if not called during test discovery
         self.pattern = pattern
         self.topLevelDirectory = topLevelDirectory
-        super(HandleFileEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class MatchPathEvent(Event):
-
     """Event fired during file matching.
 
     Plugins may return ``False`` and set ``handled`` on this event to prevent
@@ -1077,11 +1048,10 @@ class MatchPathEvent(Event):
         self.path = path
         self.name = name
         self.pattern = pattern
-        super(MatchPathEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class GetTestCaseNamesEvent(Event):
-
     """Event fired to find test case names in a test case.
 
     Plugins may return a list of names and set ``handled`` on this
@@ -1136,11 +1106,10 @@ class GetTestCaseNamesEvent(Event):
         self.extraNames = []
         self.excludedNames = []
         self.isTestMethod = isTestMethod
-        super(GetTestCaseNamesEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class ResultSuccessEvent(Event):
-
     """Event fired at end of test run to determine success.
 
     This event fires at the end of the test run and allows
@@ -1166,11 +1135,10 @@ class ResultSuccessEvent(Event):
     def __init__(self, result, success, **kw):
         self.result = result
         self.success = success
-        super(ResultSuccessEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class ResultStopEvent(Event):
-
     """Event fired when a test run is told to stop.
 
     Plugins can use this event to prevent other plugins from stopping
@@ -1191,11 +1159,10 @@ class ResultStopEvent(Event):
     def __init__(self, result, shouldStop, **kw):
         self.result = result
         self.shouldStop = shouldStop
-        super(ResultStopEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class DescribeTestEvent(Event):
-
     """Event fired to get test description.
 
 
@@ -1220,11 +1187,10 @@ class DescribeTestEvent(Event):
         self.test = test
         self.description = description
         self.errorList = errorList
-        super(DescribeTestEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class OutcomeDetailEvent(Event):
-
     """Event fired to acquire additional details about test outcome.
 
     .. attribute :: outcomeEvent
@@ -1245,11 +1211,10 @@ class OutcomeDetailEvent(Event):
     def __init__(self, outcomeEvent, **kw):
         self.outcomeEvent = outcomeEvent
         self.extraDetail = []
-        super(OutcomeDetailEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class ReportSummaryEvent(Event):
-
     """Event fired before and after summary report.
 
     .. attribute :: stopTestEvent
@@ -1276,11 +1241,10 @@ class ReportSummaryEvent(Event):
         self.stopTestEvent = stopTestEvent
         self.stream = stream
         self.reportCategories = reportCategories
-        super(ReportSummaryEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class ReportTestEvent(Event):
-
     """Event fired to report a test event.
 
     Plugins can respond to this event by producing output for the user.
@@ -1303,11 +1267,10 @@ class ReportTestEvent(Event):
     def __init__(self, testEvent, stream, **kw):
         self.testEvent = testEvent
         self.stream = stream
-        super(ReportTestEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class UserInteractionEvent(Event):
-
     """Event fired before and after user interaction.
 
     Plugins that capture stdout or otherwise prevent user interaction
@@ -1320,11 +1283,10 @@ class UserInteractionEvent(Event):
     """
 
     def __init__(self, **kw):
-        super(UserInteractionEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class CommandLineArgsEvent(Event):
-
     """Event fired after parsing of command line arguments.
 
     Plugins can respond to this event by configuring themselves or other plugins
@@ -1346,11 +1308,10 @@ class CommandLineArgsEvent(Event):
 
     def __init__(self, args, **kw):
         self.args = args
-        super(CommandLineArgsEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class CreateTestsEvent(Event):
-
     """Event fired before test loading.
 
     Plugins can take over test loading by returning a test suite and setting
@@ -1377,7 +1338,7 @@ class CreateTestsEvent(Event):
         self.loader = loader
         self.testNames = testNames
         self.module = module
-        super(CreateTestsEvent, self).__init__(**kw)
+        super().__init__(**kw)
 
 
 class CreatedTestSuiteEvent(Event):
@@ -1396,4 +1357,4 @@ class CreatedTestSuiteEvent(Event):
 
     def __init__(self, suite, **kw):
         self.suite = suite
-        super(CreatedTestSuiteEvent, self).__init__(**kw)
+        super().__init__(**kw)
